-- Spongebob_UniqueDiplomacy
-- Author: PHXHRC/OTiger
-- This file was originally made by Typhlomence

-- This is used to apply unique diplomacy responses depending on what civilization the playing is playing as
-- thanks to Ryoga's Unique Cultural Influence for some of the code (and for showing this was possible)

-- Lines to use in FireTuner to test:
-- For a line: print(Locale.ConvertTextKey("..."))
-- For a reference: for _ in DB.Query("SELECT * FROM Diplomacy_Responses WHERE Response = '...'") do print (_.LeaderType .. ", " .. _.ResponseType .. ", " .. _.Response .. ", " .. _.Bias) end

include("UniqueDiplomacyUtilsV3.lua");

-- ============================================================================
-- Enables debug statements
-- ============================================================================
local bDebug = false

function dprint(...)
  if (bDebug) then
    print(string.format(...))
  end
end

-- ============================================================================
-- Locals
-- ============================================================================

local tNeptune = {
	["LEADER_NEPTUNE"] = true,				-- Neptune from Neptunia by Morgarane
	["LEADER_VV_NEPTUNE"] = true,			-- Neptune from Neptunia by Vice Virtuoso
	["LEADER_VV_PURPLE_HEART"] = true,		-- Purple Heart from Neptunia by Vice Virtuoso
}
-- Unique diplomacy for Neptune... but not the Neptune you're expecting!

local tViking = {
	["LEADER_HARALD"] = true,				-- Harald Bluetooth of Denmark
	["LEADER_JFD_HAAKON"] = true,			-- Haakon Haakonsson of Norway by JFD
	["LEADER_VIKING_LS_MOD_CNUT"] = true,	-- Ragnar of the Vikings by LostSword
}
-- Happy Leif Ericson Day! Hinga-dinga-durgin!
-- Suprisingly, there hasn't been a mod with Leif Ericson as a leader.

local tKancolle = {
	["LEADER_KANCOLLE_NAGATO"] = true,
	["LEADER_KANCOLLEALASKA"] = true,
	["LEADER_RICHELIEU"] = true,
	["LEADER_KANCOLLEBISMARCK"] = true,
	["LEADER_SOVETSKY"] = true,
	["LEADER_KANCOLLEELIZABETH"] = true
}

local tSplatoon = {
	["LEADER_CUTTLEFISH"] = true,			-- Cap'n Cuttlefish from Splatoon by jimbilljohn
	["LEADER_PHXHRC_CUTTLEFISH"] = true,	-- Cap'n Cuttlefish from Splatoon by PHXHRC (tentative)
	["LEADER_DJOCTAVIO"] = true,			-- DJ Octavio from Splatoon by jimbilljohn
	["LEADER_PHXHRC_OCTAVIO"] = true		-- DJ Octavio from Splatoon by PHXHRC (tentative)
}
-- You're a Civ now!
-- You're a squid now!

local tFoulMouthed = {
	["LEADER_VV_BLANC"] = true,				-- Blanc from Neptunia
	["LEADER_VV_WHITE_HEART"] = true,		-- White Heart from Neptunia
	["LEADER_VV_BLANC_ULTRA"] = true,		-- Blanc (Ultra ver.) from Neptunia
	["LEADER_VV_WHITE_HEART_ULTRA"] = true,	-- White Heart (Ultra ver.) from Neptunia
	["LEADER_SENATOR_ARMSTRONG"] = true,	-- Senator Armstrong from Metal Gear Rising
	["LEADER_PIERCE_WASHINGTON"] = true	-- Pierce from Saint's Row
}
-- Four leaders? That's not *dolphin chirp* many. A reference of the classic episode, "Sailor Mouth"!
-- Incidentally, all of these leaders so far are made by Vice Virtuoso.

local tAquaman = {
	["LEADER_AQUAMAN"] = true,				-- Aquaman by KungFuMonkey52
	["LEADER_PHXHRC_AQUAMAN"] = true,		-- Aquaman by PHXHRC (tentative)
	["LEADER_AQU"] = true,					-- Aquaman by luei333 (tentative?)
}

local tMagicalGirls = {
	["LEADER_MADOKA"] = true,				-- (Ultimate) Madoka from Madoka Magica
	["LEADER_SAYAKA"] = true,				-- Sayaka from Madoka Magica
	["LEADER_ORIKO_KIRIKA"] = true,			-- Kirika from Madoka Magica
	["LEADER_NAGISA"] = true,				-- Nagisa from Madoka Magica
	["LEADER_MAMI"] = true,				    -- Mami from Madoka Magica
	["LEADER_ORIGINAL_MADOKA"] = true,		-- Madoka from Madoka Magica
	["LEADER_KYOUKO"] = true,				-- Kyoko from Madoka Magica
	["LEADER_KAORU_UMIKA"] = true,		    -- Kaoru Umika from Madoka Magica
	["LEADER_HOMURA"] = true,				-- Homura from Madoka Magica
	["LEADER_DEMON_HOMURA"] = true,         -- Demon Homura from Madoka Magica
    ["LEADER_NANOHA"] = true,               -- Nanoha from Nanoha
    ["LEADER_SAILORMOON"] = true            -- Sailor Moon by DoktorAJ
}     
-- Yes, one big local just for one line.
-- So far, all most of these Civs are by Vice Virtuoso.
-- ============================================================================
-- SpongebobUniqueResponses
-- ============================================================================
-- This function will look at the civilization the player is playing as, and make changes to the necessary lines using the above functions
function SpongebobUniqueResponses()

	local pActivePlayer = Players[Game.GetActivePlayer()]
	local sLeaderType = GameInfo.Leaders[pActivePlayer:GetLeaderType()].Type	

	if pActivePlayer ~= nil and pActivePlayer:IsAlive() and pActivePlayer:IsHuman() then
		dprint("Checking if this player is one of the leaders that Spongebob has unique lines for...")
		-- Spongebob Civs
		-- Mr. Krabs
		if (sLeaderType == "LEADER_MR_KRABS") then
			dprint("The player is playing as Mr. Krabs. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_FIRSTGREETING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEFEATED", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_DEFEATED%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_POLITE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_GREETING_POLITE_HELLO%");
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_HOSTILE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_GREETING_HOSTILE_HELLO%", 500);			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_TOO_SOON_FOR_DOF", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_TOO_SOON_FOR_DOF%");			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_TO_BEING_DENOUNCED", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_RESPONSE_TO_BEING_DENOUNCED%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DENOUNCE", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_DENOUNCE%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_COMPLIMENT", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_COMPLIMENT%");			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEMAND", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_DEMAND%");			
			ChangeDiplomacyGameText("TXT_KEY_LEADER_SPONGEBOB_WE_DISLIKE_HUMAN_PROPOSAL_2", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_WE_DISLIKE_HUMAN_PROPOSAL_2");			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_HOSTILE_HUMAN_AT_WAR", "TXT_KEY_LEADER_SPONGEBOB_MR_KRABS_GREETING_HOSTILE_HUMAN_AT_WAR%");			

		-- Patrick
		elseif (sLeaderType == "LEADER_PATRICK") then
			dprint("The player is playing as Patrick. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_FIRSTGREETING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEFEATED", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DEFEATED%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_POLITE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_GREETING_POLITE_HELLO%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_NEUTRAL_HELLO", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_GREETING_NEUTRAL_HELLO%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_HOSTILE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_GREETING_HOSTILE_HELLO%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_AT_WAR_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_GREETING_AT_WAR_HOSTILE%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOF_AI_WAR_REQUEST", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DOF_AI_WAR_REQUEST%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOF_NOT_HONORED", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DOF_NOT_HONORED%");			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DENOUNCING_FRIEND", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DENOUNCING_FRIEND%");				
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEC_FRIENDSHIP", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DEC_FRIENDSHIP%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DENOUNCE", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DENOUNCE%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_NOW_UNFORGIVABLE", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_NOW_UNFORGIVABLE%");				
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_NOW_ENEMY", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_NOW_ENEMY%");			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_COOP_WAR_YES", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_COOP_WAR_YES%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_ATTACKED_HOSTILE%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_BETRAYED", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_ATTACKED_BETRAYED%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOW_GENERIC", "TXT_KEY_LEADER_PATRICK_DOW_GENERIC%", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DOW_GENERIC%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOW_BETRAYAL", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DOW_BETRAYAL%");				
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_RESPONSE_TO_BEING_DENOUNCED", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_RESPONSE_TO_BEING_DENOUNCED%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_BOOT_KISSING", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_BOOT_KISSING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOW_REGRET", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_DOW_REGRET%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_SAD", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_ATTACKED_SAD%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_PEACE_OFFER", "TXT_KEY_LEADER_SPONGEBOB_PATRICK_PEACE_OFFER%");	
			
			
		-- Plankton
		elseif (sLeaderType == "LEADER_PLANKTON") then
			dprint("The player is playing as Plankton. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_FIRSTGREETING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEFEATED", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_DEFEATED%");			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_AT_WAR_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_GREETING_AT_WAR_HOSTILE%");			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOF_AI_WAR_REQUEST", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_DOF_AI_WAR_REQUEST%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOF_NOT_HONORED", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_DOF_NOT_HONORED%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEC_FRIENDSHIP", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_DEC_FRIENDSHIP%");	
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_ATTACKED_HOSTILE%", 500);		
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_STRONG_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_ATTACKED_STRONG_HOSTILE%", 500);	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_CAUGHT_YOUR_SPY_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_CAUGHT_YOUR_SPY_HOSTILE%");				
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_CAUGHT_YOUR_SPY_FRIENDLY", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_CAUGHT_YOUR_SPY_FRIENDLY%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_KILLED_YOUR_SPY", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_KILLED_YOUR_SPY%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_SUSPECT_YOU_OF_SPYING", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_SUSPECT_YOU_OF_SPYING%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_INFLUENTIAL_ON_HUMAN_", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_INFLUENTIAL_ON_HUMAN_%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_COOP_WAR_REQUEST", "TXT_KEY_LEADER_SPONGEBOB_PLANKTON_COOP_WAR_REQUEST%");	
			
		-- Sandy
		elseif (sLeaderType == "LEADER_SANDY") then
			dprint("The player is playing as Sandy. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_SANDY_FIRSTGREETING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEFEATED", "TXT_KEY_LEADER_SPONGEBOB_SANDY_DEFEATED%");		
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_POLITE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_SANDY_GREETING_POLITE_HELLO%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_HOSTILE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_SANDY_GREETING_HOSTILE_HELLO%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOF_NOT_HONORED", "TXT_KEY_LEADER_SPONGEBOB_SANDY_DOF_NOT_HONORED%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DENOUNCING_FRIEND", "TXT_KEY_LEADER_SPONGEBOB_SANDY_DENOUNCING_FRIEND%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_BOOT_KISSING", "TXT_KEY_LEADER_SPONGEBOB_SANDY_BOOT_KISSING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEC_FRIENDSHIP", "TXT_KEY_LEADER_SPONGEBOB_SANDY_DEC_FRIENDSHIP%");
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_INSULT_GENERIC", "TXT_KEY_LEADER_SPONGEBOB_SANDY_INSULT_GENERIC%", 500);	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_SANDY_ATTACKED_HOSTILE%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_BETRAYED", "TXT_KEY_LEADER_SPONGEBOB_SANDY_ATTACKED_BETRAYED%");
			
		-- Squidward
		elseif (sLeaderType == "LEADER_SQUIDWARD") then
			dprint("The player is playing as Squidward. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_SQUIDWARD_FIRSTGREETING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEFEATED", "TXT_KEY_LEADER_SPONGEBOB_SQUIDWARD_DEFEATED%");		
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_GREETING_REPEAT_", "TXT_KEY_LEADER_SPONGEBOB_SQUIDWARD_GREETING_REPEAT%", 500);	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_POLITE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_SQUIDWARD_GREETING_POLITE_HELLO%");		
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DEC_FRIENDSHIP", "TXT_KEY_LEADER_SPONGEBOB_SQUIDWARD_DEC_FRIENDSHIP%");	
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_COMPLIMENT", "TXT_KEY_LEADER_SPONGEBOB_SQUIDWARD_COMPLIMENT%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_INFLUENTIAL_ON_AI", "TXT_KEY_LEADER_SPONGEBOB_SQUIDWARD_INFLUENTIAL_ON_AI%");	
			
		-- King Neptune
		elseif (sLeaderType == "LEADER_KING_NEPTUNE") then
			dprint("The player is playing as King Neptune. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_KING_NEPTUNE_FIRSTGREETING%");
			
		-- Flying Dutchman
		elseif (sLeaderType == "LEADER_SQUIDWARD") then
			dprint("The player is playing as the Flying Dutchman. Setting diplomacy responses.")
			
		-- Mermaid Man and Barnacle Boy
		elseif (sLeaderType == "LEADER_MB") then
			dprint("The player is playing as Mermaid Man and Barnacle Boy. Setting diplomacy responses.")
		-- Larry
		elseif (sLeaderType == "LEADER_LARRY") then
			dprint("The player is playing as Larry. Setting diplomacy responses.")
		-- Ms. Puff
		elseif (sLeaderType == "LEADER_PUFF") then
			dprint("The player is playing as Ms. Puff. Setting diplomacy responses.")
		-- Gary
		elseif (sLeaderType == "LEADER_GARY") then
			dprint("The player is playing as Gary. Setting diplomacy responses.")




	    -- Vanilla Civs		
		-- William of the Netherlands
		elseif (sLeaderType == "LEADER_WILLIAM") then
			dprint("The player is playing as William. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_WILLIAM_FIRSTGREETING%");
		
		-- Local Civs
		-- Neptune from Neptunia
		elseif (tNeptune[sLeaderType]) then
			dprint("The player is playing as Neptune. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_NEPTUNE_FIRSTGREETING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_NEPTUNE_DEFEATED%");
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_POLITE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_NEPTUNE_GREETING_POLITE_HELLO%", 500);			
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_AT_WAR_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_NEPTUNE_GREETING_AT_WAR_HOSTILE%", 500);			
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_TRADE_REJECT_UNACCEPTABLE", "TXT_KEY_LEADER_SPONGEBOB_NEPTUNE_TRADE_REJECT_UNACCEPTABLE%", 500);		
					
		-- Viking Leaders
		elseif (tViking[sLeaderType]) then
			dprint("The player is playing as a viking. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_VIKING_FIRSTGREETING%");

		-- Aquaman
		elseif (sLeaderType == "LEADER_AQUAMAN") then
			dprint("The player is playing as Aquaman. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_AQUAMAN_FIRSTGREETING%");
			
		-- Magical Girl leaders
		elseif (tMagicalGirls[sLeaderType]) then
			dprint("The player is playing as a magical girl. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_MAGICAL_GIRL_FIRSTGREETING%");
		
		-- Splatoon leaders
		elseif (tSplatoon[sLeaderType]) then
			dprint("The player is playing as a character from Splatoon. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_SPLATOON_FIRSTGREETING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_DOF_AI_WAR_REQUEST", "TXT_KEY_LEADER_SPONGEBOB_SPLATOON_DOF_AI_WAR_REQUEST%");

			
		-- Foul Mouthed leaders
		elseif (tFoulMouthed[sLeaderType]) then
			dprint ("The player is playing as a leader who swears a lot. Setting diplomacy responses.");
			AddDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_POLITE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_FOULMOUTH_GREETING_POLITE_HELLO%", 500);
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_DENOUNCED_AI", "TXT_KEY_LEADER_SPONGEBOB_FOULMOUTH_RESPONSE_GREETING_DENOUNCED_AI%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_TO_BEING_DENOUNCED", "TXT_KEY_LEADER_SPONGEBOB_FOULMOUTH_RESPONSE_TO_BEING_DENOUNCED%");
			
		-- KanColle leaders
		elseif (tKancolle[sLeaderType]) then
			dprint("The player is playing as a character from Kantai Collection. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_KANCOLLE_FIRSTGREETING%");
			
		-- Other Civs	
		-- Togay Bey of the Tatars by LastSword
		elseif (sLeaderType == "LEADER_TATAR_LS_MOD_TOGAY") then
			dprint("The player is playing as a Tartar leader. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_TARTAR_FIRSTGREETING%");
		
		-- Santa Claus by calcul8or
		elseif (sLeaderType == "LEADER_SANTACLAUS") then
			dprint("The player is playing as Santa Claus. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_SANTACLAUS_FIRSTGREETING%");
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_SAD", "TXT_KEY_LEADER_SPONGEBOB_SANTACLAUS_ATTACKED_SAD%");
		
		-- Brett Raymer from Tanked by Karatekid1717
		elseif (sLeaderType == "LEADER_BRETT_RAYMER") then
			dprint("The player is playing as Brett Raymer. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_BRETT_RAYMER_FIRSTGREETING%");
			
	    -- Sam Houston of Texas
		elseif (sLeaderType == "LEADER_HOUSTON") then
			dprint("The player is playing as Sam Houston. Setting diplomacy responses.")
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_FIRST_GREETING", "TXT_KEY_LEADER_SPONGEBOB_HOUSTON_FIRSTGREETING%");			
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_GREETING_HOSTILE_HELLO", "TXT_KEY_LEADER_SPONGEBOB_HOUSTON_GREETING_HOSTILE_HELLO%");		
			ChangeDiplomacyResponse("LEADER_SPONGEBOB", "RESPONSE_ATTACKED_HOSTILE", "TXT_KEY_LEADER_SPONGEBOB_HOUSTON_ATTACKED_HOSTILE%");			
		end
	end
end

SpongebobUniqueResponses()
-- ============================================================================
-- Listeners
-- ============================================================================
-- Attach the above function to the correct event so that the diplomacy responses are set immediately, but only if the player IS NOT Spongebob...
for iPlayer = 0, GameDefines.MAX_MAJOR_CIVS - 1, 1 do
	local pPlayer = Players[iPlayer]
	if pPlayer ~= nil and pPlayer:IsAlive() and not pPlayer:IsHuman() and (pPlayer:GetCivilizationType() == GameInfo.Civilizations.CIVILIZATION_BIKINI_BOTTOM.ID) then
		Events.SequenceGameInitComplete.Add(SpongebobUniqueResponses);
		print("Spongebob is present but not as the player... we'll check if the diplomacy responses need to be changed at game start.");
		break
	end
end